==> dkim-milter-2.3.0.tar.gz: dkim-milter-2.3.0/libdkim/t-test71.c <==
/*
**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
**    All rights reserved.
*/

#ifndef lint
static char t_test71_c_id[] = "@(#)$Id: t-test71.c,v 1.2 2007/07/31 04:04:32 msk Exp $";
#endif /* !lint */

/* system includes */
#include <sys/types.h>
#include <assert.h>
#include <string.h>
#include <stdio.h>

/* libdkim includes */
#include "dkim.h"
#include "t-testdata.h"

#define	MAXHEADER	4096

#define	SIG1 "v=1; a=rsa-sha1; c=relaxed/simple; d=example.com; s=test; t=1172620939; bh=ll/0h2aWgG+D3ewmE4Y3pY7Ukz8=; h=Received:Received:Received:From:To:Date:Subject:Cc:Message-ID; b=JFqBAjys95FbYkal0dJULNVg6D6oxDvr+Kx/ibqTHe/FGnI/+ovcTRiloIdd4V1bHhAHopo9QIo9GJLilzEKIglGSSaO8R0/B2kT5qTs3GlP3ntAAkiCL9ERQKf5oJ6uoxbCBZtwdqasputZ0sRBg8xFt54YjPwO+qKWWhhxkIo="
#define SIG2 "v=1; a=rsa-sha1; c=relaxed/simple; d=example.com; s=test;\r\n\tt=1172620939; bh=ll/0h2aWgG+D3ewmE4Y3pY7Ukz8=; h=Received:Received:\r\n\t Received:From:To:Date:Subject:Cc:Message-ID; b=JFqBAjys95FbYkal0dJ\r\n\tULNVg6D6oxDvr+Kx/ibqTHe/FGnI/+ovcTRiloIdd4V1bHhAHopo9QIo9GJLilzEKIg\r\n\tlGSSaO8R0/B2kT5qTs3GlP3ntAAkiCL9ERQKf5oJ6uoxbCBZtwdqasputZ0sRBg8xFt\r\n\t54YjPwO+qKWWhhxkIo="


#define	XHDRNAME	"Cc: "
#define	XHDRADDR	"nosuchuser@nosuchdomain.com"
#define	XHDRVALEOL	",\r\n\t"
#define	XHDRVAL		XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR
#define	XHEADERCC	XHDRNAME XHDRVAL

/*
**  MAIN -- program mainline
**
**  Parameters:
**  	The usual.
**
**  Return value:
**  	Exit status.
*/

int
main(int argc, char **argv)
{
#ifdef TEST_KEEP_FILES
	u_int flags;
#endif /* TEST_KEEP_FILES */
	DKIM_STAT status;
	time_t fixed_time;
	DKIM *dkim;
	DKIM_LIB *lib;
	dkim_sigkey_t key;
	unsigned char hdr[MAXHEADER + 1];

	printf("*** relaxed/simple rsa-sha1 signing with large headers\n");

	/* instantiate the library */
	lib = dkim_init(NULL, NULL);
	assert(lib != NULL);

#ifdef TEST_KEEP_FILES
	/* set flags */
	flags = (DKIM_LIBFLAGS_TMPFILES|DKIM_LIBFLAGS_KEEPFILES);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FLAGS, &flags,
	                    sizeof flags);
#endif /* TEST_KEEP_FILES */

	key = KEY;

	dkim = dkim_sign(lib, JOBID, NULL, key, SELECTOR, DOMAIN,
	                 DKIM_CANON_RELAXED, DKIM_CANON_SIMPLE,
	                 DKIM_SIGN_RSASHA1, -1L, &status);
	assert(dkim != NULL);

	/* fix signing time */
	fixed_time = 1172620939;
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FIXEDTIME,
	                    &fixed_time, sizeof fixed_time);

	status = dkim_header(dkim, HEADER02, strlen(HEADER02));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER03, strlen(HEADER03));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER04, strlen(HEADER04));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER05, strlen(HEADER05));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER06, strlen(HEADER06));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER07, strlen(HEADER07));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER08, strlen(HEADER08));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, XHEADERCC, strlen(XHEADERCC));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER09, strlen(HEADER09));
	assert(status == DKIM_STAT_OK);

	status = dkim_eoh(dkim);
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY00, strlen(BODY00));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01, strlen(BODY01));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01A, strlen(BODY01A));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01B, strlen(BODY01B));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01C, strlen(BODY01C));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01D, strlen(BODY01D));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01E, strlen(BODY01E));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY02, strlen(BODY02));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY04, strlen(BODY04));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY05, strlen(BODY05));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_eom(dkim, NULL);
	assert(status == DKIM_STAT_OK);

	memset(hdr, '\0', sizeof hdr);
	status = dkim_getsighdr(dkim, hdr, sizeof hdr, 0, 0);
	assert(status == DKIM_STAT_OK);
	assert(strcmp(SIG1, hdr) == 0);

	memset(hdr, '\0', sizeof hdr);
	status = dkim_getsighdr(dkim, hdr, sizeof hdr, 75,
	                        strlen(DKIM_SIGNHEADER) + 2);
	assert(status == DKIM_STAT_OK);
	assert(strcmp(SIG2, hdr) == 0);

	status = dkim_free(dkim);
	assert(status == DKIM_STAT_OK);

	dkim_close(lib);

	return 0;
}

==> dkim-milter_2.6.0.dfsg.orig.tar.gz: dkim-milter-2.6.0.dfsg/libdkim/t-test71.c <==
/*
**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
**    All rights reserved.
*/

#ifndef lint
static char t_test71_c_id[] = "@(#)$Id: t-test71.c,v 1.3 2008/06/05 15:23:18 msk Exp $";
#endif /* !lint */

/* system includes */
#include <sys/types.h>
#include <assert.h>
#include <string.h>
#include <stdio.h>

/* libdkim includes */
#include "dkim.h"
#include "t-testdata.h"

#define	MAXHEADER	4096

#define SIG2 "v=1; a=rsa-sha1; c=relaxed/simple; d=example.com; s=test;\r\n\tt=1172620939; bh=ll/0h2aWgG+D3ewmE4Y3pY7Ukz8=; h=Received:Received:\r\n\t Received:From:To:Date:Subject:Cc:Message-ID; b=JFqBAjys95FbYkal0dJ\r\n\tULNVg6D6oxDvr+Kx/ibqTHe/FGnI/+ovcTRiloIdd4V1bHhAHopo9QIo9GJLilzEKIg\r\n\tlGSSaO8R0/B2kT5qTs3GlP3ntAAkiCL9ERQKf5oJ6uoxbCBZtwdqasputZ0sRBg8xFt\r\n\t54YjPwO+qKWWhhxkIo="


#define	XHDRNAME	"Cc: "
#define	XHDRADDR	"nosuchuser@nosuchdomain.com"
#define	XHDRVALEOL	",\r\n\t"
#define	XHDRVAL		XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR XHDRVALEOL \
			XHDRADDR
#define	XHEADERCC	XHDRNAME XHDRVAL

/*
**  MAIN -- program mainline
**
**  Parameters:
**  	The usual.
**
**  Return value:
**  	Exit status.
*/

int
main(int argc, char **argv)
{
#ifdef TEST_KEEP_FILES
	u_int flags;
#endif /* TEST_KEEP_FILES */
	DKIM_STAT status;
	time_t fixed_time;
	DKIM *dkim;
	DKIM_LIB *lib;
	dkim_sigkey_t key;
	unsigned char hdr[MAXHEADER + 1];

	printf("*** relaxed/simple rsa-sha1 signing with large headers\n");

	/* instantiate the library */
	lib = dkim_init(NULL, NULL);
	assert(lib != NULL);

#ifdef TEST_KEEP_FILES
	/* set flags */
	flags = (DKIM_LIBFLAGS_TMPFILES|DKIM_LIBFLAGS_KEEPFILES);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FLAGS, &flags,
	                    sizeof flags);
#endif /* TEST_KEEP_FILES */

	key = KEY;

	dkim = dkim_sign(lib, JOBID, NULL, key, SELECTOR, DOMAIN,
	                 DKIM_CANON_RELAXED, DKIM_CANON_SIMPLE,
	                 DKIM_SIGN_RSASHA1, -1L, &status);
	assert(dkim != NULL);

	/* fix signing time */
	fixed_time = 1172620939;
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FIXEDTIME,
	                    &fixed_time, sizeof fixed_time);

	status = dkim_header(dkim, HEADER02, strlen(HEADER02));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER03, strlen(HEADER03));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER04, strlen(HEADER04));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER05, strlen(HEADER05));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER06, strlen(HEADER06));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER07, strlen(HEADER07));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER08, strlen(HEADER08));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, XHEADERCC, strlen(XHEADERCC));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER09, strlen(HEADER09));
	assert(status == DKIM_STAT_OK);

	status = dkim_eoh(dkim);
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY00, strlen(BODY00));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01, strlen(BODY01));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01A, strlen(BODY01A));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01B, strlen(BODY01B));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01C, strlen(BODY01C));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01D, strlen(BODY01D));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01E, strlen(BODY01E));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY02, strlen(BODY02));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY04, strlen(BODY04));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY05, strlen(BODY05));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_eom(dkim, NULL);
	assert(status == DKIM_STAT_OK);

	memset(hdr, '\0', sizeof hdr);
	status = dkim_getsighdr(dkim, hdr, sizeof hdr,
	                        strlen(DKIM_SIGNHEADER) + 2);
	assert(status == DKIM_STAT_OK);
	assert(strcmp(SIG2, hdr) == 0);

	status = dkim_free(dkim);
	assert(status == DKIM_STAT_OK);

	dkim_close(lib);

	return 0;
}
